import { Serializable } from "./load/serializable.js";
import { type BaseMessage, HumanMessage } from "./messages/index.js";
/**
 * Base PromptValue class. All prompt values should extend this class.
 */
export declare abstract class BasePromptValue extends Serializable {
    abstract toString(): string;
    abstract toChatMessages(): BaseMessage[];
}
/**
 * Represents a prompt value as a string. It extends the BasePromptValue
 * class and overrides the toString and toChatMessages methods.
 */
export declare class StringPromptValue extends BasePromptValue {
    lc_namespace: string[];
    value: string;
    constructor(value: string);
    toString(): string;
    toChatMessages(): HumanMessage[];
}
/**
 * Interface for the fields of a ChatPromptValue.
 */
export interface ChatPromptValueFields {
    messages: BaseMessage[];
}
/**
 * Class that represents a chat prompt value. It extends the
 * BasePromptValue and includes an array of BaseMessage instances.
 */
export declare class ChatPromptValue extends BasePromptValue {
    lc_namespace: string[];
    lc_serializable: boolean;
    static lc_name(): string;
    messages: BaseMessage[];
    constructor(messages: BaseMessage[]);
    constructor(fields: ChatPromptValueFields);
    toString(): string;
    toChatMessages(): BaseMessage[];
}
